summaryrefslogtreecommitdiffstats
path: root/kalarm/pickfileradio.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/pickfileradio.h')
-rw-r--r--kalarm/pickfileradio.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kalarm/pickfileradio.h b/kalarm/pickfileradio.h
index 6d989d5c..a8d12383 100644
--- a/kalarm/pickfileradio.h
+++ b/kalarm/pickfileradio.h
@@ -38,7 +38,7 @@ class LineEdit;
* To achieve this, whenever the button is newly selected and the
* file name is currently blank, the file picker dialogue is displayed to choose a
* file. If the dialogue exits without a file being chosen, the radio button selection
* is reverted to the previously selected button in the parent button group.
*
* The class handles the activation of the file picker dialogue (via a virtual method
* which must be supplied by deriving a class from this one). It also handles all
@@ -50,22 +50,23 @@ class LineEdit;
class PickFileRadio : public RadioButton
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param button Push button to invoke the file picker dialogue.
* @param edit File name edit widget, or null if there is none.
* @param text Radio button's text.
* @param parent Button group which is to be the parent object for the radio button.
* @param name The name of this widget.
*/
- PickFileRadio(TQPushButton* button, LineEdit* edit, const TQString& text, TQButtonGroup* parent, const char* name = 0);
+ PickFileRadio(TQPushButton* button, LineEdit* edit, const TQString& text, TQButtonGroup* tqparent, const char* name = 0);
/** Constructor.
* The init() method must be called before the widget can be used.
* @param text Radio button's text.
* @param parent Button group which is to be the parent object for the radio button.
* @param name The name of this widget.
*/
- PickFileRadio(const TQString& text, TQButtonGroup* parent, const char* name = 0);
+ PickFileRadio(const TQString& text, TQButtonGroup* tqparent, const char* name = 0);
/** Initialises the widget.
* @param button Push button to invoke the file picker dialogue.
* @param edit File name edit widget, or null if there is none.
@@ -79,7 +80,7 @@ class PickFileRadio : public RadioButton
/** Chooses a file, for example by displaying a file selection dialogue.
* This method is called when the push button is clicked - the client
* should not activate a file selection dialogue directly.
- * @return Selected file name, or TQString::null if no selection made.
+ * @return Selected file name, or TQString() if no selection made.
*/
virtual TQString pickFile() = 0;
/** Notifies the widget of the currently selected file name.
@@ -38,7 +38,7 @@ class LineEdit;
* file name is currently blank, the file picker dialogue is displayed to choose a
* file. If the dialogue exits without a file being chosen, the radio button selection
- * is reverted to the previously selected button in the parent button group.
+ * is reverted to the previously selected button in the tqparent button group.
*
* The class handles the activation of the file picker dialogue (via a virtual method
@@ -50,22 +50,23 @@ class LineEdit;
* @param edit File name edit widget, or null if there is none.
* @param text Radio button's text.
- * @param parent Button group which is to be the parent object for the radio button.
+ * @param tqparent Button group which is to be the tqparent object for the radio button.
* @param name The name of this widget.
*/
@@ -50,22 +50,23 @@ class LineEdit;
* The init() method must be called before the widget can be used.
* @param text Radio button's text.
- * @param parent Button group which is to be the parent object for the radio button.
+ * @param tqparent Button group which is to be the tqparent object for the radio button.
* @param name The name of this widget.
*/